@@ -390,18 +390,11 @@ sub disconnect
     $self->send( close => $data ) if( $self->handshake->is_done );
 
     # Now we wait a reasonable amount of time until the client acknowledges and send us too a close confirmation according to rfc6455 section 5.1.1
-#     my $t = AnyEvent->timer( after => 3, cb => sub
-#     {
-#         $self->shutdown;
-#     });
     local $SIG{ALRM} = sub
     {
         $self->shutdown;
     };
     alarm(3);
-    # Created in start()
-    # $self->{_ae_handle}->destroy if( $self->{_ae_handle} );
-    # $self->{_ae_condvar}->send if( $self->{_ae_condvar} );
     return( $self );
 }
 
@@ -745,8 +738,6 @@ sub shutdown
 {
     my $self = shift( @_ );
     return( $self ) if( $self->disconnected );
-#     $self->{_ae_handle}->destroy if( $self->{_ae_handle} );
-#     $self->{_ae_condvar}->send if( $self->{_ae_condvar} );
     $self->socket->shutdown( SHUT_RDWR );
     $self->disconnected(1);
     return( $self );
@@ -781,8 +772,6 @@ sub uri { return( shift->_set_get_uri( 'uri', @_ ) ); }
 
 sub version { return( shift->_set_get_object_without_init( 'version', 'WebSocket::Version', @_ ) ); }
 
-sub wait { return( shift->{_ae_condvar}->wait ); }
-
 1;
 
 __END__
@@ -1141,10 +1130,6 @@ The WebSocket protocol version being used, such as C<draft-ietf-hybi-17>
 
 See L<rfc6455 about suport for multiple versions|https://datatracker.ietf.org/doc/html/rfc6455#page-26>
 
-=head2 wait
-
-Calls the L<AnyEvent/condvar>
-
 =head1 CREDITS
 
 Graham Ollis for L<AnyEvent::WebSocket::Client>, Eric Wastl for L<Net::WebSocket::Server>, Vyacheslav Tikhanovsky aka VTI for L<Protocol::WebSocket>
